@@ -7,7 +7,7 @@ options(prompt = "R> ")
 
 
 ###################################################
-### code chunk number 2: CARBayes.Rnw:419-423
+### code chunk number 2: CARBayes.Rnw:423-427
 ###################################################
 library(CARBayesdata)
 library(sf)
@@ -16,14 +16,14 @@ data(GGHB.IZ)
 
 
 ###################################################
-### code chunk number 3: CARBayes.Rnw:429-431
+### code chunk number 3: CARBayes.Rnw:433-435
 ###################################################
 head(pricedata)
 head(GGHB.IZ)
 
 
 ###################################################
-### code chunk number 4: CARBayes.Rnw:457-460
+### code chunk number 4: CARBayes.Rnw:461-464
 ###################################################
 library(dplyr)
 pricedata <- pricedata %>% mutate(logprice = log(pricedata$price))
@@ -31,38 +31,34 @@ head(pricedata)
 
 
 ###################################################
-### code chunk number 5: CARBayes.Rnw:466-468
+### code chunk number 5: CARBayes.Rnw:470-472
 ###################################################
 library(GGally)
 ggpairs(data = pricedata, columns = c(8, 3:7))
 
 
 ###################################################
-### code chunk number 6: CARBayes.Rnw:481-482
+### code chunk number 6: CARBayes.Rnw:485-486
 ###################################################
 pricedata.sf <- merge(x=GGHB.IZ, y=pricedata, by="IZ", all.x=FALSE)
 
 
 ###################################################
-### code chunk number 7: CARBayes.Rnw:490-492
+### code chunk number 7: CARBayes.Rnw:494-496
 ###################################################
 pricedata.sf <- st_transform(x=pricedata.sf, 
                              crs='+proj=longlat +datum=WGS84 +no_defs')
 
 
 ###################################################
-### code chunk number 8: CARBayes.Rnw:497-507
+### code chunk number 8: CARBayes.Rnw:501-507
 ###################################################
-library(leaflet)
-colours <- colorNumeric(palette = "YlOrRd", domain = pricedata.sf$price)
-map1 <- leaflet(data=pricedata.sf) %>% 
-    addTiles() %>% 
-    addPolygons(fillColor = ~colours(price), color="", weight=1, 
-                fillOpacity = 0.7) %>%
-    addLegend(pal = colours, values = pricedata.sf$price, opacity = 1, 
-              title="Price") %>%
-    addScaleBar(position="bottomleft")
-map1
+library(mapview)
+library(RColorBrewer)
+map1 <- mapview(pricedata.sf, zcol = "price", col.regions=brewer.pal(9, "YlOrRd"), 
+            alpha.regions=0.6, layer.name="Price", lwd=0.5, col="grey90", 
+            homebutton=FALSE) 
+removeMapJunk(map1, junk = c("zoomControl", "layersControl"))
 
 
 ###################################################
@@ -89,7 +85,7 @@ W <- nb2mat(W.nb, style="B")
 
 
 ###################################################
-### code chunk number 12: CARBayes.Rnw:729-733
+### code chunk number 12: CARBayes.Rnw:703-707
 ###################################################
 library(CARBayesdata)
 library(sf)
@@ -98,50 +94,46 @@ data(GGHB.IZ)
 
 
 ###################################################
-### code chunk number 13: CARBayes.Rnw:739-741
+### code chunk number 13: CARBayes.Rnw:713-715
 ###################################################
 head(pricedata)
 head(GGHB.IZ)
 
 
 ###################################################
-### code chunk number 14: CARBayes.Rnw:747-749
+### code chunk number 14: CARBayes.Rnw:721-723
 ###################################################
 respiratorydata.sf <- merge(x=GGHB.IZ, y=respiratorydata, by="IZ", all.x=FALSE)
 head(respiratorydata.sf)
 
 
 ###################################################
-### code chunk number 15: CARBayes.Rnw:754-756
+### code chunk number 15: CARBayes.Rnw:728-730
 ###################################################
 respiratorydata.sf <- st_transform(x=respiratorydata.sf, 
                                    crs='+proj=longlat +datum=WGS84 +no_defs')
 
 
 ###################################################
-### code chunk number 16: CARBayes.Rnw:763-773
+### code chunk number 16: CARBayes.Rnw:737-743
 ###################################################
-library(leaflet)
-colours <- colorNumeric(palette = "YlOrRd", domain = respiratorydata.sf$SMR)
-map2 <- leaflet(data=respiratorydata.sf) %>% 
-  addTiles() %>% 
-  addPolygons(fillColor = ~colours(SMR), color="", weight=1, 
-              fillOpacity = 0.7) %>%
-  addLegend(pal = colours, values = respiratorydata.sf$SMR, opacity = 1, 
-            title="SMR") %>%
-  addScaleBar(position="bottomleft")
-map2
+library(mapview)
+library(RColorBrewer)
+map2 <- mapview(respiratorydata.sf, zcol = "SMR", col.regions=brewer.pal(9, "YlOrRd"), 
+            alpha.regions=0.6, layer.name="SMR", lwd=0.5, col="grey90", 
+            homebutton=FALSE) 
+removeMapJunk(map2, junk = c("zoomControl", "layersControl"))
 
 
 ###################################################
-### code chunk number 17: CARBayes.Rnw:788-790
+### code chunk number 17: CARBayes.Rnw:758-760
 ###################################################
 W.nb <- poly2nb(respiratorydata.sf, row.names = respiratorydata.sf$IZ)
 W <- nb2mat(W.nb, style="B")
 
 
 ###################################################
-### code chunk number 18: CARBayes.Rnw:805-807
+### code chunk number 18: CARBayes.Rnw:775-777
 ###################################################
 income <- respiratorydata.sf$incomedep
 Z.incomedep <- as.matrix(dist(income, diag=TRUE, upper=TRUE)) 
